#
# spec file for package libfwnt
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname	libfwnt1
Name:           libfwnt
Version:        20210906
Release:        bp154.2.32
Summary:        Library for Windows NT data types
License:        GFDL-1.3-or-later AND LGPL-3.0-or-later
Group:          Productivity/File utilities
URL:            https://github.com/libyal/libfwnt
Source:         https://github.com/libyal/libfwnt/releases/download/%version/libfwnt-alpha-%version.tar.gz
Source2:        https://github.com/libyal/libfwnt/releases/download/%version/libfwnt-alpha-%version.tar.gz.asc
Source3:        %name.keyring
Source11:       Locale_identifier_LCID.pdf
Patch1:         system-libs.patch
BuildRequires:  %{python_module devel}
BuildRequires:  c_compiler
BuildRequires:  gettext-tools >= 0.18.1
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libcdata) >= 20210625
BuildRequires:  pkgconfig(libcerror) >= 20201121
BuildRequires:  pkgconfig(libcnotify) >= 20200913
BuildRequires:  pkgconfig(libcthreads) >= 20200508
%python_subpackages

%description
Library to provide Windows NT data type support for the libyal family of libraries.
libyal is typically used in digital forensic tools.

%package -n %{lname}
Summary:        Library for Windows NT data types
License:        LGPL-3.0-or-later
Group:          System/Libraries

%description -n %{lname}
Library to provide Windows NT data type support for the libyal family of libraries.
libyal is typically used in digital forensic tools.

%package devel
Summary:        Development files for libfwnt
License:        GFDL-1.3-or-later AND LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description devel
Library to provide Windows NT data type support for the libyal family
of libraries. libyal is typically used in digital forensic tools.

This subpackage contains libraries and header files for developing
applications that want to make use of libfwnt.

%prep
%autosetup -p1
cp %_sourcedir/*.pdf .

%build
autoreconf -fi
# OOT builds are presently broken, so we have to install
# within each python iteration now, not in %%install.
%{python_expand #
%configure --disable-static \
	--enable-python PYTHON_VERSION="%{$python_bin_suffix}"
%make_build
%make_install DESTDIR="%_builddir/rt"
%make_build clean
}

%install
mv %_builddir/rt/* %buildroot/
find %{buildroot} -type f -name "*.la" -delete -print

%check
# make check

%post   -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%license COPYING*
%{_libdir}/libfwnt.so.*

%files -n %name-devel
%license COPYING*
%doc Locale_identifier_LCID.pdf
%{_includedir}/libfwnt.h
%{_includedir}/libfwnt/
%{_libdir}/libfwnt.so
%{_libdir}/pkgconfig/libfwnt.pc
%{_mandir}/man3/libfwnt.3*

%files %python_files
%license COPYING*
%{python_sitearch}/pyfwnt.so

%changelog
* Sat Jan 22 2022 Jan Engelhardt <jengelh@inai.de>
- Enable multipython builds.
* Sun Nov 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 20210906
  * Updated security descriptor documentation
* Wed Jul 21 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 20210717
  * Unspecified changes to security descriptor
  * Added missing notify functions
* Wed May 12 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210421 (fa9d27e5)
  * No changelog was provided
- Add system-libs.patch
* Wed Dec 16 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to 0~20200723
  * Worked on LZXpress-Huffman support
  * Added LZXpress-Huffman 32-bit extended size support
* Thu Apr 30 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- remove python2 submodule
* Mon Apr 15 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- updated to 0~20181227
  * Worked on Python bindings
* Wed Oct  4 2017 Greg.Freemyer@gmail.com
- rename python-libfwnt to python2-libfwnt as expected by singlespec
- remove Provides pyfwnt as it is not versioned
* Thu Feb 16 2017 Greg.Freemyer@gmail.com
- updated to 0~20170115
- use libcstring from factory
* Thu Jul 28 2016 Greg.Freemyer@gmail.com
- update to 20160418
  * worked on Python bindings
  * worked on security descriptor support
  * worked on tests
  * 2016 update
- Add python binding subpackages for python 2 and 3
- rename PDF document to eliminate () per new security check
* Fri Jan 29 2016 Greg.Freemyer@gmail.com
- update to 20151206
  * changes in copying security identifier to string
  to work around issues with VS 2008 compilation
  * worked on lzxpress support
  * increased the maximum number of sub authorities from 10 to 15
  * code clean up
* Sun Jan 11 2015 Greg.Freemyer@gmail.com
- update to 20150104
  * 2015 refresh
- update URL to the new github site
- replace Source: field with fully defined URL
- remove DL-URL comment
- remove %%if opensuse logic.  Not needed with libyal in security:forensics
* Mon Sep  1 2014 Greg.Freemyer@gmail.com
- initial package in OBS (v0~20140105)
